pub enum AppAction {
None,
Quit,
Open(String),
Back,
Submit(FormSubmission),
Extract(ExtractFormat),
Pipe(PipeCommand),
Ai(AiAction),
}Expand description
Result of handling a key event.
Variants
None
No external action is required.
Quit
The app should quit.
Open(String)
A link or URL was requested for opening.
Back
The previous document should be restored.
Submit(FormSubmission)
A form was submitted through command or interactive form controls.
Extract(ExtractFormat)
A document extraction was requested through the command bar.
Pipe(PipeCommand)
A confirmed pipe command was requested through the command bar.
Ai(AiAction)
An explicitly requested AI action.