TerminalApp

Struct TerminalApp 

pub struct TerminalApp { /* private fields */ }
Terminal document application state.

Implementations

Source

impl TerminalApp

pub fn new(document: IndexDocument, width: usize) -> Self

Creates terminal state from a document and initial wrapping width.

pub fn with_capabilities( document: IndexDocument, width: usize, capabilities: TerminalCapabilities, ) -> Self

Creates terminal state from a document, width, and terminal capabilities.

pub const fn viewport(&self) -> Viewport

Returns the current viewport.

pub const fn mode(&self) -> &InputMode

Returns the current input mode.

Returns whether link hints are visible.

Returns whether the right-side structural sidebar is visible.

pub const fn sidebar_mode(&self) -> SessionSidebarMode

Returns the active right-sidebar mode.

pub const fn reader_profile(&self) -> ReaderProfile

Returns the active reader profile.

pub const fn reader_profile_is_auto(&self) -> bool

Returns whether the reader profile is currently automatic.

pub const fn table_mode(&self) -> TableMode

Returns the active table presentation mode.

pub const fn table_column_offset(&self) -> usize

Returns the zero-based horizontal table column offset.

pub fn set_sidebar_mode(&mut self, mode: SessionSidebarMode)

Sets the active right-sidebar mode from persisted session state.

pub fn set_url_history(&mut self, history: Vec<String>)

Replaces local URL-history suggestions.

pub fn set_response_logs(&mut self, logs: Vec<ResponseLogEntry>)

Replaces local response logs.

pub fn set_reader_profile(&mut self, profile: ReaderProfile)

Sets the active reader profile from CLI input or persisted session state.

pub fn set_reader_profile_auto(&mut self)

Enables automatic reader profile selection for the current document.

pub const fn should_quit(&self) -> bool

Returns whether the app should quit.

pub fn status(&self) -> &str

Returns the status bar text.

pub const fn repair_recipe(&self) -> &RepairRecipe

Returns the current local repair recipe.

pub fn replace_document( &mut self, document: IndexDocument, width: usize, status: String, )

Replaces the current document after an external navigation.

pub fn set_viewport_height(&mut self, height: usize)

Updates the viewport height and clamps the offset.

pub fn handle_key(&mut self, key: KeyEvent) -> AppAction

Handles a terminal key event.

pub fn render(&mut self, frame: &mut Frame<'_>)

Renders the app into a ratatui frame.