Theme

Struct Theme 

pub struct Theme {
Show 22 fields pub foreground: Color, pub muted: Color, pub document_title: Color, pub heading: Color, pub link: Color, pub list: Color, pub code: Color, pub table: Color, pub image: Color, pub form: Color, pub quote: Color, pub region: Color, pub bold: Color, pub italic: Color, pub error: Color, pub warning: Color, pub success: Color, pub info: Color, pub current_line: Color, pub accent: Color, pub prompt: Color, pub status: Color,
}
Terminal theme colors.

Fields

foreground: Color

Primary text color.

muted: Color

Secondary text color.

document_title: Color

Document title color.

heading: Color

Heading color.

link: Color

Link color.

list: Color

List marker color.

code: Color

Code block color.

table: Color

Table row color.

image: Color

Image proxy color.

form: Color

Form color.

quote: Color

Quote color.

region: Color

Semantic page region marker color.

bold: Color

Bold inline text color.

italic: Color

Italic inline text color.

error: Color

Error color.

warning: Color

Warning color.

success: Color

Success color.

info: Color

Info color.

current_line: Color

Mild current-line background color.

accent: Color

Highlight color.

prompt: Color

Always-visible command prompt color.

status: Color

Status bar foreground color.

Implementations

Source

impl Theme

pub fn for_profile(profile: ReaderProfile) -> Self

Builds the default deterministic theme for a reader profile.

pub fn for_profile_with_capabilities( profile: ReaderProfile, capabilities: TerminalCapabilities, ) -> Self

Builds a deterministic theme for a reader profile and terminal capability set.