TuiDocumentResult

Struct TuiDocumentResult 

pub struct TuiDocumentResult {
    pub document: IndexDocument,
    pub visited_url: Option<String>,
    pub response_log: Option<ResponseLogEntry>,
}
Result returned by the host after navigation or form submission.

Fields

document: IndexDocument

Document to display.

visited_url: Option<String>

URL to add to local URL-history suggestions.

response_log: Option<ResponseLogEntry>

Redacted response log entry to add to the hidden logs sidebar.

Implementations

Source

impl TuiDocumentResult

pub fn new(document: IndexDocument) -> Self

Creates a result from a document.

pub fn with_visited_url(self, url: impl Into<String>) -> Self

Adds a URL-history entry.

pub fn with_response_log(self, log: ResponseLogEntry) -> Self

Adds a response log entry.