pub struct Theme {Show 22 fields
pub foreground: Color,
pub muted: Color,
pub document_title: Color,
pub heading: Color,
pub link: Color,
pub list: Color,
pub code: Color,
pub table: Color,
pub image: Color,
pub form: Color,
pub quote: Color,
pub region: Color,
pub bold: Color,
pub italic: Color,
pub error: Color,
pub warning: Color,
pub success: Color,
pub info: Color,
pub current_line: Color,
pub accent: Color,
pub prompt: Color,
pub status: Color,
}Expand description
Terminal theme colors.
Fields
foreground: ColorPrimary text color.
muted: ColorSecondary text color.
document_title: ColorDocument title color.
heading: ColorHeading color.
link: ColorLink color.
list: ColorList marker color.
code: ColorCode block color.
table: ColorTable row color.
image: ColorImage proxy color.
form: ColorForm color.
quote: ColorQuote color.
region: ColorSemantic page region marker color.
bold: ColorBold inline text color.
italic: ColorItalic inline text color.
error: ColorError color.
warning: ColorWarning color.
success: ColorSuccess color.
info: ColorInfo color.
current_line: ColorMild current-line background color.
accent: ColorHighlight color.
prompt: ColorAlways-visible command prompt color.
status: ColorStatus bar foreground color.
Implementations
Sourceimpl Theme
impl Theme
Sourcepub fn for_profile(profile: ReaderProfile) -> Self
pub fn for_profile(profile: ReaderProfile) -> Self
Builds the default deterministic theme for a reader profile.
Sourcepub fn for_profile_with_capabilities(
profile: ReaderProfile,
capabilities: TerminalCapabilities,
) -> Self
pub fn for_profile_with_capabilities( profile: ReaderProfile, capabilities: TerminalCapabilities, ) -> Self
Builds a deterministic theme for a reader profile and terminal capability set.